[PATCH 1/2] ISOImage needs to look at /run/install/source for the mounted image (#879142).

Chris Lumens clumens at redhat.com
Mon Dec 3 16:59:28 UTC 2012


---
 pyanaconda/constants.py            | 2 +-
 pyanaconda/packaging/yumpayload.py | 4 ++--
 pyanaconda/ui/gui/spokes/source.py | 3 ++-
 3 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/pyanaconda/constants.py b/pyanaconda/constants.py
index c4c0007..7ff5020 100644
--- a/pyanaconda/constants.py
+++ b/pyanaconda/constants.py
@@ -78,7 +78,7 @@ ANACONDA_CLEANUP = "anaconda-cleanup"
 ROOT_PATH = "/mnt/sysimage"
 MOUNT_DIR = "/mnt/install"
 DRACUT_REPODIR = "/run/install/repo"
-DRACUT_ISODIR = "/run/install/isodir"
+DRACUT_ISODIR = "/run/install/source"
 ISO_DIR = MOUNT_DIR + "/isodir"
 INSTALL_TREE = MOUNT_DIR + "/source"
 BASE_REPO_NAME = "anaconda"
diff --git a/pyanaconda/ui/gui/spokes/source.py b/pyanaconda/ui/gui/spokes/source.py
index 33518b5..3e940ef 100644
--- a/pyanaconda/ui/gui/spokes/source.py
+++ b/pyanaconda/ui/gui/spokes/source.py
@@ -459,7 +459,8 @@ class SourceSpoke(NormalSpoke):
 
             self.data.method.method = "harddrive"
             self.data.method.partition = part.name
-            self.data.method.dir = self._currentIsoFile
+            # The / gets stripped off by payload.ISOImage
+            self.data.method.dir = "/" + self._currentIsoFile
             if (old_source.method == "harddrive" and
                 old_source.partition == self.data.method.partition and
                 old_source.dir == self.data.method.dir):
diff --git a/pyanaconda/packaging/yumpayload.py b/pyanaconda/packaging/yumpayload.py
index 0c5ea8c..f1de826 100644
--- a/pyanaconda/packaging/yumpayload.py
+++ b/pyanaconda/packaging/yumpayload.py
@@ -500,11 +500,11 @@ reposdir=%s
         if not self.data.method.method == "harddrive":
             return None
         # This could either be mounted to INSTALL_TREE or on
         # DRACUT_REPODIR if dracut did the mount.
         dev = get_mount_device(INSTALL_TREE)
         if dev:
             return dev[len(ISO_DIR)+1:]
-        dev = get_mount_device(DRACUT_REPODIR)
+        dev = get_mount_device(DRACUT_ISODIR)
         if dev:
             return dev[len(DRACUT_ISODIR)+1:]
         return None
@@ -500,11 +500,11 @@ reposdir=%s
             return None
         # This could either be mounted to INSTALL_TREE or on
-        # DRACUT_REPODIR if dracut did the mount.
+        # DRACUT_ISODIR if dracut did the mount.
         dev = get_mount_device(INSTALL_TREE)
         if dev:
-- 
1.7.11.2



More information about the anaconda-patches mailing list